/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */

import { get } from 'lodash';
import {
  SERVICE_NAME,
  TRANSACTION_TYPE,
  SERVICE_AGENT_NAME
} from '../../../common/constants';

export async function getService({ serviceName, setup }) {
  const { start, end, esFilterQuery, client, config } = setup;

  const params = {
    index: [
      config.get('apm_oss.errorIndices'),
      config.get('apm_oss.transactionIndices')
    ],
    body: {
      size: 0,
      query: {
        bool: {
          filter: [
            { term: { [SERVICE_NAME]: serviceName } },
            {
              range: {
                '@timestamp': {
                  gte: start,
                  lte: end,
                  format: 'epoch_millis'
                }
              }
            }
          ]
        }
      },
      aggs: {
        types: {
          terms: { field: TRANSACTION_TYPE, size: 100 }
        },
        agents: {
          terms: { field: SERVICE_AGENT_NAME, size: 1 }
        }
      }
    }
  };

  if (esFilterQuery) {
    params.body.query.bool.filter.push(esFilterQuery);
  }

  const resp = await client('search', params);

  return {
    service_name: serviceName,
    types: resp.aggregations.types.buckets.map(bucket => bucket.key),
    agent_name: get(resp, 'aggregations.agents.buckets[0].key')
  };
}
